@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.cloud.osconfig_v1.services.os_config_service import pagers
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
@@ -380,13 +382,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def execute_patch_job(
         self,
-        request: patch_jobs.ExecutePatchJobRequest = None,
+        request: Union[patch_jobs.ExecutePatchJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_jobs.PatchJob:
@@ -394,7 +397,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         job.
 
         Args:
-            request (google.cloud.osconfig_v1.types.ExecutePatchJobRequest):
+            request (Union[google.cloud.osconfig_v1.types.ExecutePatchJobRequest, dict]):
                 The request object. A request message to initiate
                 patching across Compute Engine instances.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -443,10 +446,10 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def get_patch_job(
         self,
-        request: patch_jobs.GetPatchJobRequest = None,
+        request: Union[patch_jobs.GetPatchJobRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_jobs.PatchJob:
@@ -455,7 +458,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         of completed jobs.
 
         Args:
-            request (google.cloud.osconfig_v1.types.GetPatchJobRequest):
+            request (Union[google.cloud.osconfig_v1.types.GetPatchJobRequest, dict]):
                 The request object. Request to get an active or
                 completed patch job.
             name (str):
@@ -524,9 +527,9 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def cancel_patch_job(
         self,
-        request: patch_jobs.CancelPatchJobRequest = None,
+        request: Union[patch_jobs.CancelPatchJobRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_jobs.PatchJob:
@@ -534,7 +537,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         Canceled patch jobs cannot be restarted.
 
         Args:
-            request (google.cloud.osconfig_v1.types.CancelPatchJobRequest):
+            request (Union[google.cloud.osconfig_v1.types.CancelPatchJobRequest, dict]):
                 The request object. Message for canceling a patch job.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -582,17 +585,17 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def list_patch_jobs(
         self,
-        request: patch_jobs.ListPatchJobsRequest = None,
+        request: Union[patch_jobs.ListPatchJobsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPatchJobsPager:
         r"""Get a list of patch jobs.
 
         Args:
-            request (google.cloud.osconfig_v1.types.ListPatchJobsRequest):
+            request (Union[google.cloud.osconfig_v1.types.ListPatchJobsRequest, dict]):
                 The request object. A request message for listing patch
                 jobs.
             parent (str):
@@ -660,17 +663,17 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def list_patch_job_instance_details(
         self,
-        request: patch_jobs.ListPatchJobInstanceDetailsRequest = None,
+        request: Union[patch_jobs.ListPatchJobInstanceDetailsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPatchJobInstanceDetailsPager:
         r"""Get a list of instance details for a given patch job.
 
         Args:
-            request (google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest):
+            request (Union[google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest, dict]):
                 The request object. Request to list details for all
                 instances that are part of a patch job.
             parent (str):
@@ -742,19 +745,19 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def create_patch_deployment(
         self,
-        request: patch_deployments.CreatePatchDeploymentRequest = None,
+        request: Union[patch_deployments.CreatePatchDeploymentRequest, dict] = None,
         *,
         parent: str = None,
         patch_deployment: patch_deployments.PatchDeployment = None,
         patch_deployment_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Create an OS Config patch deployment.
 
         Args:
-            request (google.cloud.osconfig_v1.types.CreatePatchDeploymentRequest):
+            request (Union[google.cloud.osconfig_v1.types.CreatePatchDeploymentRequest, dict]):
                 The request object. A request message for creating a
                 patch deployment.
             parent (str):
@@ -782,7 +785,6 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 -  Must end with a number or a letter.
                 -  Must be unique within the project.
 
-
                 This corresponds to the ``patch_deployment_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -845,17 +847,17 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def get_patch_deployment(
         self,
-        request: patch_deployments.GetPatchDeploymentRequest = None,
+        request: Union[patch_deployments.GetPatchDeploymentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> patch_deployments.PatchDeployment:
         r"""Get an OS Config patch deployment.
 
         Args:
-            request (google.cloud.osconfig_v1.types.GetPatchDeploymentRequest):
+            request (Union[google.cloud.osconfig_v1.types.GetPatchDeploymentRequest, dict]):
                 The request object. A request message for retrieving a
                 patch deployment.
             name (str):
@@ -920,17 +922,17 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def list_patch_deployments(
         self,
-        request: patch_deployments.ListPatchDeploymentsRequest = None,
+        request: Union[patch_deployments.ListPatchDeploymentsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListPatchDeploymentsPager:
         r"""Get a page of OS Config patch deployments.
 
         Args:
-            request (google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest):
+            request (Union[google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest, dict]):
                 The request object. A request message for listing patch
                 deployments.
             parent (str):
@@ -1000,17 +1002,17 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     def delete_patch_deployment(
         self,
-        request: patch_deployments.DeletePatchDeploymentRequest = None,
+        request: Union[patch_deployments.DeletePatchDeploymentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Delete an OS Config patch deployment.
 
         Args:
-            request (google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest):
+            request (Union[google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest, dict]):
                 The request object. A request message for deleting a
                 patch deployment.
             name (str):
@@ -1062,6 +1064,19 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             request, retry=retry, timeout=timeout, metadata=metadata,
         )
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
