@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.osconfig_v1alpha.services.os_config_zonal_service import pagers
@@ -198,12 +200,14 @@ class OsConfigZonalServiceAsyncClient:
 
     async def create_os_policy_assignment(
         self,
-        request: os_policy_assignments.CreateOSPolicyAssignmentRequest = None,
+        request: Union[
+            os_policy_assignments.CreateOSPolicyAssignmentRequest, dict
+        ] = None,
         *,
         parent: str = None,
         os_policy_assignment: os_policy_assignments.OSPolicyAssignment = None,
         os_policy_assignment_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -220,7 +224,7 @@ class OsConfigZonalServiceAsyncClient:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to create an OS
                 policy assignment
             parent (:class:`str`):
@@ -249,7 +253,6 @@ class OsConfigZonalServiceAsyncClient:
                 -  Must end with a number or a letter.
                 -  Must be unique within the project.
 
-
                 This corresponds to the ``os_policy_assignment_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -330,11 +333,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def update_os_policy_assignment(
         self,
-        request: os_policy_assignments.UpdateOSPolicyAssignmentRequest = None,
+        request: Union[
+            os_policy_assignments.UpdateOSPolicyAssignmentRequest, dict
+        ] = None,
         *,
         os_policy_assignment: os_policy_assignments.OSPolicyAssignment = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -350,7 +355,7 @@ class OsConfigZonalServiceAsyncClient:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to update an OS
                 policy assignment
             os_policy_assignment (:class:`google.cloud.osconfig_v1alpha.types.OSPolicyAssignment`):
@@ -443,10 +448,10 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_os_policy_assignment(
         self,
-        request: os_policy_assignments.GetOSPolicyAssignmentRequest = None,
+        request: Union[os_policy_assignments.GetOSPolicyAssignmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> os_policy_assignments.OSPolicyAssignment:
@@ -457,7 +462,7 @@ class OsConfigZonalServiceAsyncClient:
         revision ID in the ``name`` parameter.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to get an OS
                 policy assignment
             name (:class:`str`):
@@ -530,10 +535,12 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_os_policy_assignments(
         self,
-        request: os_policy_assignments.ListOSPolicyAssignmentsRequest = None,
+        request: Union[
+            os_policy_assignments.ListOSPolicyAssignmentsRequest, dict
+        ] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentsAsyncPager:
@@ -543,7 +550,7 @@ class OsConfigZonalServiceAsyncClient:
         returned.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest, dict]):
                 The request object. A request message to list OS policy
                 assignments for a parent resource
             parent (:class:`str`):
@@ -611,10 +618,12 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_os_policy_assignment_revisions(
         self,
-        request: os_policy_assignments.ListOSPolicyAssignmentRevisionsRequest = None,
+        request: Union[
+            os_policy_assignments.ListOSPolicyAssignmentRevisionsRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentRevisionsAsyncPager:
@@ -622,7 +631,7 @@ class OsConfigZonalServiceAsyncClient:
         OS policy assignment.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest, dict]):
                 The request object. A request message to list revisions
                 for a OS policy assignment
             name (:class:`str`):
@@ -692,10 +701,12 @@ class OsConfigZonalServiceAsyncClient:
 
     async def delete_os_policy_assignment(
         self,
-        request: os_policy_assignments.DeleteOSPolicyAssignmentRequest = None,
+        request: Union[
+            os_policy_assignments.DeleteOSPolicyAssignmentRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -714,7 +725,7 @@ class OsConfigZonalServiceAsyncClient:
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest, dict]):
                 The request object. A request message for deleting a OS
                 policy assignment.
             name (:class:`str`):
@@ -796,10 +807,12 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_instance_os_policies_compliance(
         self,
-        request: instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest = None,
+        request: Union[
+            instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> instance_os_policies_compliance.InstanceOSPoliciesCompliance:
@@ -807,7 +820,7 @@ class OsConfigZonalServiceAsyncClient:
         Compute Engine VM instance.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest, dict]):
                 The request object. A request message for getting OS
                 policies compliance data for the given Compute Engine VM
                 instance.
@@ -892,10 +905,13 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_instance_os_policies_compliances(
         self,
-        request: instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest = None,
+        request: Union[
+            instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest,
+            dict,
+        ] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstanceOSPoliciesCompliancesAsyncPager:
@@ -903,7 +919,7 @@ class OsConfigZonalServiceAsyncClient:
         Engine VM instances in the specified zone.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest, dict]):
                 The request object. A request message for listing OS
                 policies compliance data for all Compute Engine VMs in
                 the given location.
@@ -981,10 +997,10 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_inventory(
         self,
-        request: inventory.GetInventoryRequest = None,
+        request: Union[inventory.GetInventoryRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> inventory.Inventory:
@@ -992,7 +1008,7 @@ class OsConfigZonalServiceAsyncClient:
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.GetInventoryRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetInventoryRequest, dict]):
                 The request object. A request message for getting
                 inventory data for the specified VM.
             name (:class:`str`):
@@ -1068,10 +1084,10 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_inventories(
         self,
-        request: inventory.ListInventoriesRequest = None,
+        request: Union[inventory.ListInventoriesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInventoriesAsyncPager:
@@ -1079,7 +1095,7 @@ class OsConfigZonalServiceAsyncClient:
         specified zone.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.ListInventoriesRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListInventoriesRequest, dict]):
                 The request object. A request message for listing
                 inventory data for all VMs in the specified location.
             parent (:class:`str`):
@@ -1157,10 +1173,10 @@ class OsConfigZonalServiceAsyncClient:
 
     async def get_vulnerability_report(
         self,
-        request: vulnerability.GetVulnerabilityReportRequest = None,
+        request: Union[vulnerability.GetVulnerabilityReportRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> vulnerability.VulnerabilityReport:
@@ -1169,7 +1185,7 @@ class OsConfigZonalServiceAsyncClient:
         vulnerability reports associated with them.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest, dict]):
                 The request object. A request message for getting the
                 vulnerability report for the specified VM.
             name (:class:`str`):
@@ -1241,10 +1257,10 @@ class OsConfigZonalServiceAsyncClient:
 
     async def list_vulnerability_reports(
         self,
-        request: vulnerability.ListVulnerabilityReportsRequest = None,
+        request: Union[vulnerability.ListVulnerabilityReportsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListVulnerabilityReportsAsyncPager:
@@ -1252,7 +1268,7 @@ class OsConfigZonalServiceAsyncClient:
         the specified zone.
 
         Args:
-            request (:class:`google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest`):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest, dict]):
                 The request object. A request message for listing
                 vulnerability reports for all VM instances in the
                 specified location.
@@ -1329,6 +1345,12 @@ class OsConfigZonalServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
