@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.osconfig_v1alpha.services.os_config_zonal_service import pagers
@@ -430,16 +432,19 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def create_os_policy_assignment(
         self,
-        request: os_policy_assignments.CreateOSPolicyAssignmentRequest = None,
+        request: Union[
+            os_policy_assignments.CreateOSPolicyAssignmentRequest, dict
+        ] = None,
         *,
         parent: str = None,
         os_policy_assignment: os_policy_assignments.OSPolicyAssignment = None,
         os_policy_assignment_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -456,7 +461,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.CreateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to create an OS
                 policy assignment
             parent (str):
@@ -485,7 +490,6 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
                 -  Must end with a number or a letter.
                 -  Must be unique within the project.
 
-
                 This corresponds to the ``os_policy_assignment_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -570,11 +574,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def update_os_policy_assignment(
         self,
-        request: os_policy_assignments.UpdateOSPolicyAssignmentRequest = None,
+        request: Union[
+            os_policy_assignments.UpdateOSPolicyAssignmentRequest, dict
+        ] = None,
         *,
         os_policy_assignment: os_policy_assignments.OSPolicyAssignment = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -590,7 +596,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.UpdateOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to update an OS
                 policy assignment
             os_policy_assignment (google.cloud.osconfig_v1alpha.types.OSPolicyAssignment):
@@ -687,10 +693,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def get_os_policy_assignment(
         self,
-        request: os_policy_assignments.GetOSPolicyAssignmentRequest = None,
+        request: Union[os_policy_assignments.GetOSPolicyAssignmentRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> os_policy_assignments.OSPolicyAssignment:
@@ -701,7 +707,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         revision ID in the ``name`` parameter.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetOSPolicyAssignmentRequest, dict]):
                 The request object. A request message to get an OS
                 policy assignment
             name (str):
@@ -774,10 +780,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def list_os_policy_assignments(
         self,
-        request: os_policy_assignments.ListOSPolicyAssignmentsRequest = None,
+        request: Union[
+            os_policy_assignments.ListOSPolicyAssignmentsRequest, dict
+        ] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentsPager:
@@ -787,7 +795,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         returned.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentsRequest, dict]):
                 The request object. A request message to list OS policy
                 assignments for a parent resource
             parent (str):
@@ -859,10 +867,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def list_os_policy_assignment_revisions(
         self,
-        request: os_policy_assignments.ListOSPolicyAssignmentRevisionsRequest = None,
+        request: Union[
+            os_policy_assignments.ListOSPolicyAssignmentRevisionsRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListOSPolicyAssignmentRevisionsPager:
@@ -870,7 +880,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         OS policy assignment.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListOSPolicyAssignmentRevisionsRequest, dict]):
                 The request object. A request message to list revisions
                 for a OS policy assignment
             name (str):
@@ -946,10 +956,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def delete_os_policy_assignment(
         self,
-        request: os_policy_assignments.DeleteOSPolicyAssignmentRequest = None,
+        request: Union[
+            os_policy_assignments.DeleteOSPolicyAssignmentRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -968,7 +980,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         projects.locations.osPolicyAssignments.operations.cancel <https://cloud.google.com/compute/docs/osconfig/rest/v1alpha/projects.locations.osPolicyAssignments.operations/cancel>`__.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.DeleteOSPolicyAssignmentRequest, dict]):
                 The request object. A request message for deleting a OS
                 policy assignment.
             name (str):
@@ -1054,10 +1066,12 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def get_instance_os_policies_compliance(
         self,
-        request: instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest = None,
+        request: Union[
+            instance_os_policies_compliance.GetInstanceOSPoliciesComplianceRequest, dict
+        ] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> instance_os_policies_compliance.InstanceOSPoliciesCompliance:
@@ -1065,7 +1079,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         Compute Engine VM instance.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetInstanceOSPoliciesComplianceRequest, dict]):
                 The request object. A request message for getting OS
                 policies compliance data for the given Compute Engine VM
                 instance.
@@ -1155,10 +1169,13 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def list_instance_os_policies_compliances(
         self,
-        request: instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest = None,
+        request: Union[
+            instance_os_policies_compliance.ListInstanceOSPoliciesCompliancesRequest,
+            dict,
+        ] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInstanceOSPoliciesCompliancesPager:
@@ -1166,7 +1183,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         Engine VM instances in the specified zone.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListInstanceOSPoliciesCompliancesRequest, dict]):
                 The request object. A request message for listing OS
                 policies compliance data for all Compute Engine VMs in
                 the given location.
@@ -1249,10 +1266,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def get_inventory(
         self,
-        request: inventory.GetInventoryRequest = None,
+        request: Union[inventory.GetInventoryRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> inventory.Inventory:
@@ -1260,7 +1277,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         no associated inventory, the message ``NOT_FOUND`` is returned.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.GetInventoryRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetInventoryRequest, dict]):
                 The request object. A request message for getting
                 inventory data for the specified VM.
             name (str):
@@ -1336,10 +1353,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def list_inventories(
         self,
-        request: inventory.ListInventoriesRequest = None,
+        request: Union[inventory.ListInventoriesRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListInventoriesPager:
@@ -1347,7 +1364,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         specified zone.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.ListInventoriesRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListInventoriesRequest, dict]):
                 The request object. A request message for listing
                 inventory data for all VMs in the specified location.
             parent (str):
@@ -1425,10 +1442,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def get_vulnerability_report(
         self,
-        request: vulnerability.GetVulnerabilityReportRequest = None,
+        request: Union[vulnerability.GetVulnerabilityReportRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> vulnerability.VulnerabilityReport:
@@ -1437,7 +1454,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         vulnerability reports associated with them.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.GetVulnerabilityReportRequest, dict]):
                 The request object. A request message for getting the
                 vulnerability report for the specified VM.
             name (str):
@@ -1509,10 +1526,10 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
 
     def list_vulnerability_reports(
         self,
-        request: vulnerability.ListVulnerabilityReportsRequest = None,
+        request: Union[vulnerability.ListVulnerabilityReportsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListVulnerabilityReportsPager:
@@ -1520,7 +1537,7 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         the specified zone.
 
         Args:
-            request (google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest):
+            request (Union[google.cloud.osconfig_v1alpha.types.ListVulnerabilityReportsRequest, dict]):
                 The request object. A request message for listing
                 vulnerability reports for all VM instances in the
                 specified location.
@@ -1599,6 +1616,19 @@ class OsConfigZonalServiceClient(metaclass=OsConfigZonalServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
