@@ -16,6 +16,7 @@
 import proto  # type: ignore
 
 from google.protobuf import timestamp_pb2  # type: ignore
+from google.type import date_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -70,6 +71,7 @@ class Inventory(proto.Message):
 
     class OsInfo(proto.Message):
         r"""Operating system information for the VM.
+
         Attributes:
             hostname (str):
                 The VM hostname.
@@ -105,6 +107,14 @@ class Inventory(proto.Message):
 
     class Item(proto.Message):
         r"""A single piece of inventory on a VM.
+
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             id (str):
                 Identifier for this item, unique across items
@@ -120,9 +130,11 @@ class Inventory(proto.Message):
                 to its specific details.
             installed_package (google.cloud.osconfig_v1alpha.types.Inventory.SoftwarePackage):
                 Software package present on the VM instance.
+                This field is a member of `oneof`_ ``details``.
             available_package (google.cloud.osconfig_v1alpha.types.Inventory.SoftwarePackage):
                 Software package available to be installed on
                 the VM instance.
+                This field is a member of `oneof`_ ``details``.
         """
 
         class OriginType(proto.Enum):
@@ -162,39 +174,58 @@ class Inventory(proto.Message):
 
     class SoftwarePackage(proto.Message):
         r"""Software package information of the operating system.
+
+        This message has `oneof`_ fields (mutually exclusive fields).
+        For each oneof, at most one member field can be set at the same time.
+        Setting any member of the oneof automatically clears all other
+        members.
+
+        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
         Attributes:
             yum_package (google.cloud.osconfig_v1alpha.types.Inventory.VersionedPackage):
                 Yum package info. For details about the yum package manager,
                 see
                 https://access.redhat.com/documentation/en-us/red_hat_enterprise_linux/6/html/deployment_guide/ch-yum.
+                This field is a member of `oneof`_ ``details``.
             apt_package (google.cloud.osconfig_v1alpha.types.Inventory.VersionedPackage):
                 Details of an APT package.
                 For details about the apt package manager, see
                 https://wiki.debian.org/Apt.
+                This field is a member of `oneof`_ ``details``.
             zypper_package (google.cloud.osconfig_v1alpha.types.Inventory.VersionedPackage):
                 Details of a Zypper package. For details about the Zypper
                 package manager, see
                 https://en.opensuse.org/SDB:Zypper_manual.
+                This field is a member of `oneof`_ ``details``.
             googet_package (google.cloud.osconfig_v1alpha.types.Inventory.VersionedPackage):
                 Details of a Googet package.
                 For details about the googet package manager,
                 see  https://github.com/google/googet.
+                This field is a member of `oneof`_ ``details``.
             zypper_patch (google.cloud.osconfig_v1alpha.types.Inventory.ZypperPatch):
                 Details of a Zypper patch. For details about the Zypper
                 package manager, see
                 https://en.opensuse.org/SDB:Zypper_manual.
+                This field is a member of `oneof`_ ``details``.
             wua_package (google.cloud.osconfig_v1alpha.types.Inventory.WindowsUpdatePackage):
                 Details of a Windows Update package. See
                 https://docs.microsoft.com/en-us/windows/win32/api/_wua/ for
                 information about Windows Update.
+                This field is a member of `oneof`_ ``details``.
             qfe_package (google.cloud.osconfig_v1alpha.types.Inventory.WindowsQuickFixEngineeringPackage):
                 Details of a Windows Quick Fix engineering
                 package. See
                 https://docs.microsoft.com/en-
                 us/windows/win32/cimwin32prov/win32-quickfixengineering
                 for info in Windows Quick Fix Engineering.
+                This field is a member of `oneof`_ ``details``.
             cos_package (google.cloud.osconfig_v1alpha.types.Inventory.VersionedPackage):
                 Details of a COS package.
+                This field is a member of `oneof`_ ``details``.
+            windows_application (google.cloud.osconfig_v1alpha.types.Inventory.WindowsApplication):
+                Details of Windows Application.
+                This field is a member of `oneof`_ ``details``.
         """
 
         yum_package = proto.Field(
@@ -242,6 +273,12 @@ class Inventory(proto.Message):
             oneof="details",
             message="Inventory.VersionedPackage",
         )
+        windows_application = proto.Field(
+            proto.MESSAGE,
+            number=9,
+            oneof="details",
+            message="Inventory.WindowsApplication",
+        )
 
     class VersionedPackage(proto.Message):
         r"""Information related to the a standard versioned package.
@@ -264,6 +301,7 @@ class Inventory(proto.Message):
 
     class ZypperPatch(proto.Message):
         r"""Details related to a Zypper Patch.
+
         Attributes:
             patch_name (str):
                 The name of the patch.
@@ -319,6 +357,7 @@ class Inventory(proto.Message):
 
         class WindowsUpdateCategory(proto.Message):
             r"""Categories specified by the Windows Update.
+
             Attributes:
                 id (str):
                     The identifier of the windows update
@@ -374,6 +413,39 @@ class Inventory(proto.Message):
             proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,
         )
 
+    class WindowsApplication(proto.Message):
+        r"""Contains information about a Windows application as retrieved from
+        the Windows Registry. For more information about these fields, see
+
+        `Windows Installer Properties for the Uninstall
+        Registry <https://docs.microsoft.com/en-us/windows/win32/msi/uninstall-registry-key>`__\ {:
+        class="external" }
+
+        Attributes:
+            display_name (str):
+                The name of the application or product.
+            display_version (str):
+                The version of the product or application in
+                string format.
+            publisher (str):
+                The name of the manufacturer for the product
+                or application.
+            install_date (google.type.date_pb2.Date):
+                The last time this product received service.
+                The value of this property is replaced each time
+                a patch is applied or removed from the product
+                or the command-line option is used to repair the
+                product.
+            help_link (str):
+                The internet address for technical support.
+        """
+
+        display_name = proto.Field(proto.STRING, number=1,)
+        display_version = proto.Field(proto.STRING, number=2,)
+        publisher = proto.Field(proto.STRING, number=3,)
+        install_date = proto.Field(proto.MESSAGE, number=4, message=date_pb2.Date,)
+        help_link = proto.Field(proto.STRING, number=5,)
+
     name = proto.Field(proto.STRING, number=3,)
     os_info = proto.Field(proto.MESSAGE, number=1, message=OsInfo,)
     items = proto.MapField(proto.STRING, proto.MESSAGE, number=2, message=Item,)
